#################
How to contribute
#################

Contributions are always welcome. If you want to submit a patch,
please respect the following rules:

- Open a pull request on the appropriate repository
- Respect `PEP8 <https://www.python.org/dev/peps/pep-0008/>`_
- Prefer double quotes (") over single quotes (')
- Document your patch and respect `PEP 257 <https://www.python.org/dev/peps/pep-0257/>`_
- Add unit tests and make sure the global coverage does not decrease

If all those steps are validated, your contribution will generally be
integrated.
